==> m4e_sdk-0.0.3-dev.6.tar.gz: lib/src/data/services/m4e_user_service.dart <==
import 'package:data_connection_checker/data_connection_checker.dart';

import '../../m4e_sdk_initialize.dart';
import '../api/apis.dart';
import '../../core/core.dart';
import '../../m4e_forms/m4e_forms.dart';
import '../../models/models.dart';

/// Exposes SDK User Api methods
///
/// Accessing the instantiated `M4eUserService` methods
/// is done by:
///
/// ```
/// final _userService = M4eUserService();
///
/// final _isAuthenticated = await _userService.registerUser(M4eUserForm userForm);
/// ```
///
class M4eUserService {
  final UserApi _userApi;
  final AuthApi _authApi;
  final DataConnectionChecker _connectionChecker;

  M4eUserService({
    UserApi userApi,
    AuthApi authApi,
    DataConnectionChecker connectionChecker,
  })  : _userApi = userApi ?? m4eSDK<UserApi>(),
        _authApi = authApi ?? m4eSDK<AuthApi>(),
        _connectionChecker =
            connectionChecker ?? m4eSDK<DataConnectionChecker>();

  /// Returns authenticated `M4eUser`
  ///
  /// Throws `AuthException` with `NO_AUTH_USER` error
  /// code if no user is authenticated
  ///
  /// Throws `ServerException` if call to server fails
  ///
  /// Throws `ServerException` with `NO_INTERNET_CONNECTION` error
  /// code device is not connected to the internet
  ///
  Future<M4eUser> getM4eUser() async {
    if ((await _connectionChecker.hasConnection) ?? false) {
      try {
        final _token = await _authApi.getAuthTokenFromCache();

        return await _userApi.getM4eUser(_token.id);
      } catch (e) {
        rethrow;
      }
    }

    throw M4eExceptionMessages.kNoInternetConnectionException;
  }

  /// Creates an `M4eUser` and returns created `M4eUniqueId`
  ///
  /// Throws `AuthException` with `NO_AUTH_USER` error
  /// code if no user is authenticated
  ///
  /// Throws `ServerException` if call to server fails
  ///
  /// Throws `ServerException` with `NO_INTERNET_CONNECTION` error
  /// code device is not connected to the internet
  ///
  Future<M4eUniqueId> registerUser(M4eUserForm userForm) async {
    if ((await _connectionChecker.hasConnection) ?? false) {
      try {
        final _token = await _authApi.getAuthTokenFromCache();

        final _m4eUser = await _userApi.registerM4eUser(_token.id, userForm);

        // TODO: Implement caching key-pair on registration success

        return _m4eUser;
      } catch (e) {
        rethrow;
      }
    }

    throw M4eExceptionMessages.kNoInternetConnectionException;
  }
}

==> m4e_sdk-0.0.4-dev.10.tar.gz: lib/src/data/services/m4e_user_service.dart <==
import 'package:data_connection_checker/data_connection_checker.dart';

import '../../m4e_sdk_initialize.dart';
import '../api/apis.dart';
import '../../core/core.dart';
import '../../m4e_forms/m4e_forms.dart';
import '../../models/models.dart';

/// Exposes SDK User Api methods
///
/// Accessing the instantiated `M4eUserService` methods
/// is done by:
///
/// ```
/// final _userService = M4eUserService();
///
/// final _isAuthenticated = await _userService.registerUser(M4eUserForm userForm);
/// ```
///
class M4eUserService {
  final UserApi _userApi;
  final AuthApi _authApi;
  final DataConnectionChecker _connectionChecker;

  M4eUserService({
    UserApi userApi,
    AuthApi authApi,
    DataConnectionChecker connectionChecker,
  })  : _userApi = userApi ?? m4eSDK<UserApi>(),
        _authApi = authApi ?? m4eSDK<AuthApi>(),
        _connectionChecker =
            connectionChecker ?? m4eSDK<DataConnectionChecker>();

  /// Returns authenticated `M4eUser`
  ///
  /// Throws `AuthException` with `NO_AUTH_CREDENTIAL` error
  /// code if no auth-credential is found
  ///
  /// Throws `ServerException` if call to server fails
  ///
  /// Throws `ServerException` with `NO_INTERNET_CONNECTION` error
  /// code device is not connected to the internet
  ///
  Future<M4eUser> getM4eUser() async {
    if ((await _connectionChecker.hasConnection) ?? false) {
      try {
        final _credential = await _authApi.getUserCredentialsFromCache();

        return await _userApi.getM4eUser(_credential.phoneNumber);
      } catch (e) {
        rethrow;
      }
    }

    throw M4eExceptionMessages.kNoInternetConnectionException;
  }

  /// Creates an `M4eUser` and returns created `M4eUniqueId`
  ///
  /// Throws `AuthException` with `NO_AUTH_USER` error
  /// code if no user is authenticated
  ///
  /// Throws `ServerException` if call to server fails
  ///
  /// Throws `ServerException` with `NO_INTERNET_CONNECTION` error
  /// code device is not connected to the internet
  ///
  Future<M4eUniqueId> createM4eUser(M4eUserForm userForm) async {
    if ((await _connectionChecker.hasConnection) ?? false) {
      try {
        final _token = await _authApi.getAuthTokenFromCache();

        final _m4eUserId = await _userApi.createM4eUser(_token.id, userForm);

        return _m4eUserId;
      } catch (e) {
        rethrow;
      }
    }

    throw M4eExceptionMessages.kNoInternetConnectionException;
  }
}
